@@ -32,15 +32,19 @@ global STATE
 global STATE_DEFAULT
 global current_slideshow
 global interface_root
+global interface_thread
 global logger
 global refresh_daemon
 global status_label
 global http_label
 global ws_label
+global reset_ppt_button
 global http_server
+global icon
 scheduler = None
 current_slideshow = None
 interface_root = None
+interface_thread = None
 CONFIG_FILE = r'''..\ppt-control.ini'''
 LOGFILE = r'''..\ppt-control.log'''
 logger = None
@@ -50,12 +54,18 @@ http_label = None
 ws_label = None
 ws_daemon = None
 http_server = None
+reset_ppt_button = None
+icon = None
 
 
 class Handler(server.SimpleHTTPRequestHandler):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, directory=os.path.dirname(os.path.realpath(__file__)) + r'''\static''')
         
+    def log_request(self, code='-', size='-'):
+        return
+
+        
     def translate_path(self, path):
         """Translate a /-separated PATH to the local filename syntax.
 
@@ -82,10 +92,10 @@ class Handler(server.SimpleHTTPRequestHandler):
                 try:
                     path = config.prefs["Main"]["cache"] + "\\" + current_slideshow.name()
                 except Exception as e:
-                    path = os.path.join(os.path.dirname(os.path.realpath(__file__)), r'''\static\black.jpg''') + '/'
+                    path = "black.jpg"
                     logger.warning("Failed to get current slideshow name: ", e)
             else:
-                path = os.path.join(os.path.dirname(os.path.realpath(__file__)), r'''\static\black.jpg''') + '/'
+                path = "black.jpg"
                 return path
             words.pop(0)
         else:
@@ -224,6 +234,7 @@ def restart_http():
         http_server = None
         refresh_status()
     start_http()
+    time.sleep(0.5)
     refresh_status()
 
 def start_ws():
@@ -391,7 +402,7 @@ class Slideshow:
                     attempts += 1
             elif slide == self.total_slides() + 1:
                 try:
-                    shutil.copyfileobj(open(os.path.dirname(os.path.realpath(__file__)), r'''\static\black.jpg''', 'rb'), open(destination, 'wb'))
+                    shutil.copyfileobj(open(os.path.dirname(os.path.realpath(__file__)) + r'''\static\black.jpg''', 'rb'), open(destination, 'wb'))
                 except Exception as e:
                     logger.warning("Failed to copy black slide: " + str(e))
             else:
@@ -418,18 +429,28 @@ def refresh_interval():
         time.sleep(0.5)
 
 def refresh_status():
-    if status_label is not None:
-        status_label.config(text="PowerPoint status: " + ("not " if not STATE["connected"] else "") +  "connected")
-        http_label.config(text="HTTP server: " + ("not " if http_server is None else "") +  "running")
-        #ws_label.config(text="WebSocket server: " + ("not " if ws_daemon is not None or not ws_daemon.is_alive() else "") +  "running")
+    if interface_root is not None and interface_root.state == "normal":
+        logger.debug("Refreshing UI")
+        if status_label is not None:
+            status_label.config(text="PowerPoint status: " + ("not " if not STATE["connected"] else "") +  "connected")
+        if http_label is not None:
+            http_label.config(text="HTTP server: " + ("not " if http_server is None else "") +  "running")
+            #ws_label.config(text="WebSocket server: " + ("not " if ws_daemon is not None or not ws_daemon.is_alive() else "") +  "running")
+        if reset_ppt_button is not None:
+            reset_ppt_button.config(state = tk.DISABLED if not STATE["connected"] else tk.NORMAL)
 
 def connect_ppt():
     global STATE
     global refresh_daemon
     if STATE["connected"] == 1:
         logger.info("Disconnected from PowerPoint instance")
+        icon.notify("Disconnected from PowerPoint instance")
+        if reset_ppt_button is not None:
+            reset_ppt_button.config(state = tk.DISABLED)
         refresh_daemon.do_run = False
         STATE = copy(STATE_DEFAULT)
+        if icon is not None:
+            refresh_menu()
         refresh_status()
         logger.debug("State is now " + str(STATE))
     while True:
@@ -440,6 +461,9 @@ def connect_ppt():
             STATE["connected"] = 1
             STATE["current"] = current_slideshow.current_slide()
             STATE["total"] = current_slideshow.total_slides()
+            icon.notify("Connected to PowerPoint instance")
+            if icon is not None:
+                refresh_menu()
             refresh_status()
             logger.info("Connected to PowerPoint instance")
             refresh_daemon = threading.Thread(name="refresh_daemon", target=refresh_interval)
@@ -460,16 +484,22 @@ def on_closing():
     global status_label
     global http_label
     global ws_label
+    global interface_thread
     status_label = None
     http_label = None
     ws_label = None
+    logger.debug("Destroying interface root")
     interface_root.destroy()
+    logger.debug("Destroying interface thread")
+    interface_thread.root.quit()
+    interface_thread = None
     
 def open_settings(_=None):
     global interface_root
+    global interface_thread
     interface_root = tk.Tk()
     interface_root.protocol("WM_DELETE_WINDOW", on_closing)
-    interface_root.iconphoto(False, tk.PhotoImage(file="static/icons/ppt.png"))
+    interface_root.iconphoto(False, tk.PhotoImage(file=os.path.dirname(os.path.realpath(__file__)) + r'''\static\icons\ppt.png'''))
     interface_root.geometry("600x300+300+300")
     app = Interface(interface_root)
     interface_thread = threading.Thread(target=interface_root.mainloop())
@@ -495,6 +525,7 @@ class Interface(ttk.Frame):
         global status_label
         global http_label
         global ws_label
+        global reset_ppt_button
         self.parent.title("ppt-control")
         self.style = ttk.Style()
         #self.style.theme_use("default")
@@ -509,13 +540,14 @@ class Interface(ttk.Frame):
         save_button.place(x=400, y=280)
 
         reset_ppt_button = ttk.Button(self, text="Reconnect", command=connect_ppt)
+        reset_ppt_button.config(state = tk.DISABLED)
         reset_ppt_button.place(x=300, y=10)
 
         reset_http_button = ttk.Button(self, text="Restart", command=restart_http)
         reset_http_button.place(x=300, y=30)
 
-        reset_ws_button = ttk.Button(self, text="Restart", command=null_action)
-        reset_ws_button.place(x=300, y=50)
+        #reset_ws_button = ttk.Button(self, text="Restart", command=null_action)
+        #reset_ws_button.place(x=300, y=50)
 
         status_label = ttk.Label(self)
         status_label.place(x=10,y=10)
@@ -529,13 +561,24 @@ class Interface(ttk.Frame):
         refresh_status()
         
         
+def exit_action(icon):
+    logger.debug("User requested shutdown")
+    icon.visible = False
+    icon.stop()
+
+def refresh_menu():
+    icon.menu = (pystray.MenuItem("Status: " + "dis"*(not STATE["connected"]) + "connected", lambda: null_action(), enabled=False),
+            pystray.MenuItem("Stop", lambda: exit_action(icon)),
+            pystray.MenuItem("Settings", lambda: open_settings(), enabled=False)
+            )
 
 def show_icon():
+    global icon
     logger.debug("Starting system tray icon")
-    menu = (pystray.MenuItem("Status", lambda: null_action(), enabled=False),
-            pystray.MenuItem("Restart", lambda: start()),
-            pystray.MenuItem("Settings", lambda: open_settings()))
-    icon = pystray.Icon("ppt-control", Image.open(os.path.dirname(os.path.realpath(__file__)) + r'''\static\icons\ppt.ico'''), "ppt-control", menu)
+    icon = pystray.Icon("ppt-control")
+    icon.icon = Image.open(os.path.dirname(os.path.realpath(__file__)) + r'''\static\icons\ppt.ico''')
+    icon.title = "ppt-control"
+    refresh_menu()
     icon.visible = True
     icon.run(setup=start)
 
@@ -579,6 +622,7 @@ def start_interface():
 
     # Start systray icon and server
     show_icon()
+    sys.exit(0)
 
 if __name__ == "__main__":
     start_interface()
