@@ -4,6 +4,7 @@ import obspython as obs
 import asyncio
 import websockets
 import threading
+import logging, logging.handlers
 from time import sleep
 
 PORT_DEFAULT = 5678
@@ -30,12 +31,18 @@ HOTKEY_DESC_LAST = 'Last PowerPoint slide'
 HOTKEY_DESC_BLACK = 'Black PowerPoint slide'
 HOTKEY_DESC_WHITE = 'White PowerPoint slide'
 
+LOG_LEVEL = logging.WARNING
+
 global cmd
 global attempts
+global logger
 cmd = ""
 hostname = HOSTNAME_DEFAULT
 port = PORT_DEFAULT
 attempts = 0
+logger = None
+
+logging.basicConfig()
 
 async def communicate():
     async with websockets.connect("ws://%s:%s" % (hostname, port), ping_interval=None) as websocket:
@@ -48,24 +55,27 @@ async def communicate():
                     cmd = ""
                     await websocket.send('{"action": "%s"}' % cmd_temp)
                 except websockets.ConnectionClosed as exc:
+                    logger.info("Failed to send command {}: {}".format(cmd_temp, str(exc)))
+                    cmd = cmd_temp
                     attempts += 1
                     if attempts == 4:
-                        print("Failed to send command after {} attempts - aborting connection".format(attempts))
+                        logger.info("Failed to send command {} after {} attempts - aborting connection".format(cmd_temp, attempts))
                         attempts = 0
                         cmd = ""
-                        raise websockets.exceptions.ConnectionClosedError(1006, "Sending command failed after {} attempts".format(attempts))
+                        break
             await asyncio.sleep(0.05 + 0.5*attempts**2)
 
 def run_ws():
     while True:
+        logger.debug("Attempting to connect")
         try:
             asyncio.set_event_loop(asyncio.new_event_loop())
             asyncio.get_event_loop().run_until_complete(communicate())
-        except (OSError, websockets.exceptions.ConnectionClosedError):
+        except (OSError, websockets.exceptions.ConnectionClosedError) as e:
             # No server available - just keep trying
             pass
         except Exception as e:
-            print("Failed to connect to websocket: {} - {}".format(type(e), e))
+            logger.warning("Failed to connect to websocket: {} - {}".format(type(e), e))
         finally:
             sleep(1)
 
@@ -79,6 +89,7 @@ def script_load(settings):
     global hotkey_id_last
     global hotkey_id_black
     global hotkey_id_white
+    global logger
 
     hotkey_id_first = register_and_load_hotkey(settings, HOTKEY_NAME_FIRST, HOTKEY_DESC_FIRST, first_slide)
     hotkey_id_prev = register_and_load_hotkey(settings, HOTKEY_NAME_PREV, HOTKEY_DESC_PREV, prev_slide)
@@ -87,10 +98,20 @@ def script_load(settings):
     hotkey_id_black = register_and_load_hotkey(settings, HOTKEY_NAME_BLACK, HOTKEY_DESC_BLACK, black)
     hotkey_id_white = register_and_load_hotkey(settings, HOTKEY_NAME_WHITE, HOTKEY_DESC_WHITE, white)
 
+    # Set up logging
+    log_formatter = logging.Formatter("%(asctime)s [%(threadName)-12.12s] [%(levelname)-7.7s]  %(message)s")
+    logger = logging.getLogger("ppt_control_obs")
+    logger.setLevel(LOG_LEVEL)
+    logger.propagate = False
+    console_handler = logging.StreamHandler()
+    console_handler.setFormatter(log_formatter)
+    console_handler.setLevel(LOG_LEVEL)
+    logger.addHandler(console_handler)
+
     ws_daemon = threading.Thread(name="ws_daemon", target=run_ws)
     ws_daemon.setDaemon(True)
     ws_daemon.start()
-    print("Started websocket client")
+    logger.info("Started websocket client")
 
 def script_unload():
     obs.obs_hotkey_unregister(first_slide)
